Orbit::Application.routes.draw do

  mount Ckeditor::Engine => '/ckeditor'

  resources :sessions

  

  get "logout", to: "sessions#destroy", as: "logout"

  get "/pages/edit_view" => "pages#edit_view"
  get "/pages/preview" => "pages#preview"
  get "/pages/get_categories" => "pages#get_categories"
  get "/pages/get_member_attributes" => 'pages#get_member_attributes'
  post "/pages/update_item_position" => "pages#update_item_position"
  post "/pages/save_member_frontend_fields" => 'pages#save_member_frontend_fields'

  get "/page_parts/getwidgets" => "page_parts#getwidgets"
  get "/page_parts/info" => "page_parts#info"
  get "/page_parts/edit_sub_part" => "page_parts#edit_sub_part"
  get "/admin/license_denied" => "store_api#render_license_denied"

  #routes for google to callback after omniauth
  get 'auth/:provider/callback', to: 'sessions#google_callback'
  get 'auth/:provider/remove', to: 'sessions#google_remove'
  get 'auth/google/result', to: 'sessions#google_result'
  get 'auth/google/result', to: 'sessions#google_result'
  get 'auth/failure', to: 'sessions#google_faliure'
  resources :pages
  resources :page_parts do
      member do
        patch 'update_sub_part'
      end
    end

  get "/module/:name" => "home#index"
  get "/module/:name/show" => "home#show"
  post "/store/confirmation" => "store_api#confirmation"
  post "/store/install_module" => "store_api#install_module"
  post "/store/uninstall_module" => "store_api#uninstall_module"
  post "/store/restart_srever_after_install" => "store_api#restart_server_after_install"
  get "/feeds/channel_lists" => 'store_api#get_channel_lists'

  # The priority is based upon order of creation: first created -> highest priority.
  # See how all your routes lay out with "rake routes".

  # You can have the root of your site routed with "root"
  root 'pages#home'
  get 'admin/authorizations/modal_select/:module' => 'admin/authorizations#modal_select', :as => :modal_select_authorizations
  match 'admin/authorizations/add_users/:module' => 'admin/authorizations#add_users', :as => :add_users_authorizations, via: [:get, :post]
  match 'admin/authorizations/add_roles/:module' => 'admin/authorizations#add_roles', :as => :add_roles_authorizations, via: [:get, :post]
  match 'admin/authorizations/remove_users/:module' => 'admin/authorizations#remove_users', :as => :remove_users_authorizations, via: [:delete]

  locales = Site.first.in_use_locales rescue I18n.available_locales

  scope "(:locale)", locale: Regexp.new((locales+[:zh_cn]).join("|")) do
    
    get "sitemap.xml" => "sitemaps#sitemap_xml", as: "sitemap", defaults: { format: "xml" }

    get 'users/form' => "users#form_page"
    get 'users/role_page' => "users#role_page"
    get 'users/check_availability' => "users#check_availability"
    get 'users/confirmation' => "users#confirmation"
    get 'users/get_role_statuses' => "users#get_role_statuses"
    patch 'users/role_update' => "users#role_update"
    patch 'users/basic_info_update' => "users#basic_info_update"

    resources :users do
      collection do
        get 'confirm_user'
        get 'post_confirmation'
      end
    end




    # Facebook routes

    get "/facebook/register_fb" => "facebook#register_fb"
    get "/facebook/get_friends" => "facebook#get_friends"
    get "/facebook/get_feed" => "facebook#get_feed"
    get "/facebook/disconnect" => "facebook#disconnect"
    get "/facebook/server" => "facebook#server_redirect"
    get "/facebook/profile_import" => "facebook#profile_import"

    resources :passwords
    # resources :members do
    #   collection do
    #     get ':name-:uid', to: 'members#show', as: :display
    #   end
    # end

    namespace :admin do
      resources :dashboards do
        collection do
          get 'reload_all_content'
          get 'reload_most_visited'
          get 'reload_recent_update'
          get 'get_cpu_usage'
          get 'get_mem_usage'
          get 'get_disk_usage'
          get 'get_month_traffic'
        end
      end

      get "members/get_role_fields/:id" => "members#get_role_fields", :as => :get_role_fields      
      get "members/import_members" => "members#import_members"      
      get "members/unapproved_members" => "members#unapproved_members"
      
      resources :members do
        collection do
          get 'edit_order_card'
          get 'edit_order_list'
          post 'update_order_card'
          post 'update_order_list'
          post 'import_members'
          post 'download_export'
        end
        match "setting_account" => "members#setting_account" ,:as => :setting_account, via: [:get, :post]
        match "edit_passwd" => "members#edit_passwd" ,:as => :edit_passwd, via: [:get, :post]
        match "accept_member" => "members#accept_member" ,:as => :accept_member, via: [:get, :post]
        match "edit_privilege" => "members#edit_privilege" ,:as => :edit_privilege, via: [:get, :post]
      end
      
      # GROUPS START HERE
      get "groups/categories" => 'groups#categories'
      post "groups/create_category" => 'groups#create_category'
      post "groups/:group_id/remove_user" => 'groups#remove_user'
      post "groups/:group_id/toggle_admin" => 'groups#toggle_admin'
      get "groups/existing_member_template" => 'groups#get_existing_member_template'
      get "groups/public" => 'groups#public_groups'
      patch "groups/updatecategory/:category_id" => 'groups#update_category'
      get "posts/:id" => 'groups#showpost'
      post "posts/image" => 'groups#upload_photo'
      post "posts/file" => 'groups#upload_file'
      get "posts/file/:id" => "groups#download_file"
      delete "posts/:id" => "groups#deletepost"
      get "post/:id/edit" => "groups#editpost"
      patch "post/:id/updatepost" => "groups#updatepost"
      post "posts/comment" => 'groups#new_comment'

      resources :groups do 
        get "newpost" => 'groups#newpost'
        post "createpost" => 'groups#createpost'
        get "members" => 'groups#members'
      end


      get 'members/:name-:uid/:show_plugin_profile' => "members#show", :as=> :show_plugin_profile

      resources :personal_plugins

      resources :roles do
        get 'role_field'
        get 'add_attribute_field'
        post 'toggle'
      end

      resources :member_infos

      resources :role_statuses do
        post 'toggle'
      end

      get 'select_emails' => 'member_selects#select_emails', :as => "select_emails"

      resources :module_apps do
        resources :categories do
          collection do
            post 'create_in_form'
          end
          member do
            post 'toggle'
          end
        end
        resources :tags do
          collection do
            post 'add_to_default'
            post 'add_from_default'
            post 'create_in_form'
            post 'delete_tags'
            post 'merge'
            post 'remove_default'
            post 'update_included_default'
          end
        end
      end

      resources :assets do
        collection do
          post 'file_upload'
          get 'delete'
          post 'delete_files'
        end
      end

      get 'authorizations(/:module)' => 'authorizations#index', :as => :authorizations
      resources :authorizations
      resources :items
      resources :categories do
        member do
          post 'toggle'
        end
      end
      resources :tags do
        collection do
          post 'add_to_default'
          post 'add_from_default'
          post 'delete_tags'
          post 'merge'
          post 'remove_default'
          post 'update_included_default'
        end
      end

        resources :sites do
	       get 'mail_setting'
	       get 'site_info'
	       get 'responsive_setting'
	       get 'search_engine'
	       get 'sitemap'
	       get 'sitemap_frontend'
	       get 'sitemap_toggle', :on => :member
	       get 'system_info'
	       get 'ui_theme'
	       get 'change_design'
	       get 'reset_default_locale'
	       get 'preference'
	       get 'update_manager'
	       get 'get_update_history'
	       get 'check_updates'
	       get 'update_orbit'
         get 'bundle_install'
	       get 'restart_server'
         get 'delete_mail_log'
	     end

      resources :designs do
        collection do
          get 'upload_package'
          get 'delete'
          post 'upload_package'
        end
        member do
          post 'edit_file'  => 'designs#edit_file'
          post 'update_file' => 'designs#update_file'
          post 'upload_image' => 'designs#upload_image'
        end
      end
      get 'design_list' => 'designs#design_list'
      get 'module_store' => 'module_store#index'
      get 'module_store/show' => 'module_store#show'
      post 'module_store/update_module' => 'module_store#update_module'
      get 'module_store/download' => 'module_store#download'
      get 'module_store/remove_module' => 'module_store#remove_module'
      get 'module_store/toggle_module' => 'module_store#toggle_module'
      post 'module_store/restart' => 'module_store#restart'
      get 'module_store/modules_to_update' => 'module_store#modules_to_update'

      #store routes

      get "/store/check_credentials" => "store#check_credentials"
      get "/store/register_form" => "store#register_form"
      post "/store/register_site" => "store#register_site"
      post "/store/authorize_default_modules" => "store#authorize_default_modules"
      get "/store/check_permissions" => "store#check_permissions"
      get "/store/template_store" => "store#template_store"
      get "/store/app_store" => "store#app_store"
      get  "/store/send_email" => "store#send_email"


      get "import" => "import#index"
      get "import/check_url" => "import#check_url"
      get "import/module_categories" => "import#module_categories"
      get "import/module_data_list" => "import#module_data_list"
      get "import/module_data" => "import#module_data"
      post "import/rss2_news" => "import#rss2_news"
      post "import/rss2_archive" => "import#rss2_archive"
      get "import/rss2_pages" => "import#rss2_pages"
      post "import/rss2_child_page" => "import#rss2_child_page"
      get "import/rss2_pages_info" => "import#rss2_pages_info"
      get "import/get_import_status" => "import#get_import_status"
      post "import/rss2_galleries" => "import#rss2_galleries"
      post "import/rss2_album_image" => "import#rss2_album_image"
      post "import/rss2_links" => "import#rss2_links"
      post "import/rss2_members" => "import#rss2_members"
      post "import/rss2_members_info" => "import#rss2_members_info"
      get "import/import_plugin" => "import#import_plugin"
      post "import/clean_old_data" => "import#clean_old_data"
    end

    get 'mobile', to: 'pages#home'
    get 'mobile/:page(/:page)(/:page)(/:page)', to: 'pages#show', constraints: KeywordConstraint.new

    get ':page(/:page)(/:page)(/:page)', to: 'pages#show', constraints: KeywordConstraint.new
    get '(/:page)(/:page)(/:page)/members(/:name-:uid)', to: 'pages#show'
    get '(/:page)(/:page)(/:page)/member(/:name-:uid)', to: 'pages#show'
    resources :pages
  end
    namespace :admin do
      # Directs /admin/products/* to Admin::ProductsController
      # (app/controllers/admin/products_controller.rb)
      resources :users
    end
end